pylxd
~~~~~

.. image:: http://img.shields.io/pypi/v/pylxd.svg
    :target: https://pypi.python.org/pypi/pylxd
.. image:: https://github.com/canonical/pylxd/actions/workflows/tests.yml/badge.svg
    :target: https://github.com/canonical/pylxd
.. image:: https://codecov.io/github/canonical/pylxd/coverage.svg?branch=main
    :target: https://codecov.io/github/canonical/pylxd
.. image:: https://readthedocs.org/projects/pylxd/badge/?version=latest
    :target: https://pylxd.readthedocs.io/en/latest/?badge=latest

A Python library for interacting with the LXD REST API.

Installation
=============
.. code-block:: console

  # Create a virtual environment
  python3 -m venv myvenv
  cd myvenv

  # Activate the virtual environment
  . bin/activate
  # Install pyLXD in it
  pip install pylxd

Bug reports
===========

Bug reports can be filed on the `GitHub repository
<https://github.com/canonical/pylxd/issues/new>`_.

Support and discussions
=======================

We use the `LXD category on Ubuntu's Discourse
<https://discourse.ubuntu.com/c/lxd/126>`_.

If you prefer live discussions, some of us also hang out in
`#lxd
<https://web.libera.chat/#lxd>`_ on irc.libera.chat.

LXD Documentation: `https://documentation.ubuntu.com/lxd/en/latest/
<https://documentation.ubuntu.com/lxd/en/latest/>`_

PyLXD API Documentation: `https://pylxd.readthedocs.io/en/latest/
<https://pylxd.readthedocs.io/en/latest/>`_

Contributing to pyLXD
=====================

If you wish to contribute to pyLXD please read the `Contributing Guide
<https://pylxd.readthedocs.io/en/latest/contributing.html>`_, particularly
around unit tests, integration tests and signing commits.
